/* defaults.js -- HIN default rules and actions

   Copyright 2013, 2014 by John K. Hinsdale.  See LICENSE.html for terms of use.
*/

// Default actions
var GLOBAL__default_actions = [
    { name: "Cancel",
      enabled: true,
      description: "Cancel the entire request",
      action: "cancel"
    },
    { name: "Drop Headers",
      enabled: true,
      description: "Request headers to drop, always",
      action: [ [ "drop_request_header", "Referer" ],
                [ "drop_request_header", "X-Referer" ],
                [ "drop_request_header", "X-Client-Data" ],
                [ "drop_request_header", "X-Chrome-Variations" ],
                [ "drop_request_header", "X-Chrome-UMA-Enabled" ]
              ]
    },
    { name: "No Cookies",
      enabled: true,
      description: "Disable cookies for the request by suppressing Cookie: and Set-Cookie:",
      action: [ [ "drop_request_header", "Cookie" ],
                [ "drop_response_header", "Set-Cookie"]
              ]
    },
    { name: "User-Agent",
      enabled: true,
      description: "Use less identifying User-Agent",
      action: [ "set_request_header", "User-Agent",
                "Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2049.0 Safari/537.36",
                false
              ],
    },
    { name: "No Compression",
      enabled: true,
      description: "Developers only!  Turn off compression, e.g., for transport-level debugging, by suppressing Accept-Encoding:",
      action: [ "drop_request_header", "Accept-Encoding" ]
    },
    { name: "Block and Redirect",
      enabled: true,
      description: "Redirect blocked URL to page that displays it, with reason message, and allows log/alert side-effect at the target server.",
      action: [ "redirect", "http://www.alma.com/chromium/hin/blocked.cgi?url=__URL__&msg=Blocked+by+policy" ]
    },
    { name: "Example: Auto-authorize",
      enabled: true,
      description: "Automatically send HTTP Basic credentials for a specific user@realm (not secure!)",
      action: [ "authorize", "testuser", "testpass" ]
    },
    { name: "Example: Alert",
      enabled: true,
      description: "Example of alert action - use sparingly!",
      action: [ "alert", "An example alert has been triggered for:\nHTTP __method__  __url__" ]
    },
    { name: "Debug",
      enabled: true,
      description: "When debug globally enabled, include request/response activity for the matched request",
      action: "debug"
    },
    { name: "Scrub CSP back-doors",
      enabled: true,
      description: "Remove inappropriate Chromium back-door URLs (clients*.google.com) from Content-Security-Policy: headers",
      action: [ "set_response_header", "Content-Security-Policy", [
                [ "(^|\\s+)https://clients[0-9].google.com", "" ]
          ], false ]
    },
    { name: "No Cache Digest Tracking",
      enabled: true,
      description: "Prevent cache-header based tracking by discarding potentially identifying content digests.  If-None-Match may not be effective.",
      action: [
          [ "drop_request_header", "If-None-Match" ],
          [ "drop_response_header", "ETag" ],
          [ "drop_response_header", "Content-MD5" ]
      ]
    },
    { name: "No Cache Timestamp Tracking",
      enabled: true,
      description: "Prevent cache-header based tracking by reducing the granularity of most last-modified timestamps",
      action: [ "set_response_header", "Last-Modified", [ [ "(\\d\\d:\\d\\d):\\d\\d", "$1:00" ] ], false ]
    }
];

// Default rules
var GLOBAL__default_rules = [
    { name: "Default",
      description: "Default action, matches everything",
      enabled: true,
      match: true,
      action: [ "Drop Headers",
                "User-Agent"
              ]
    },
    { name: "Block List",
      description: "URLs to block (i.e., cancel), always",
      enabled: true,
      match: [ "url", "contains",
               [
                   "google-analytics",
                   ".gexperiments",
                   "metric.gstatic.com",
                   "google.com/insights/consumer",
                   "xhr/logXhrAction?",            // news.google.com -> untrappable clients[1-9].google.com
                   "analytics.yahoo.com",
                   "//searchassist.verizon.com/"
               ]
             ],
      action: "Cancel"
    },
    { name: "Anonymize Google Search",
      description: "Opt out of Google search logging, while remaining logged in for other services (e.g., Gmail, Calendar)",
      enabled: true,
      match: [ "or",
               [ "url", "equals", "https://www.google.com/" ],
               [ "url", "contains", [
                   "google.com/_/chrome/newtab",
                   "google.com/async/newtab",
                   "google.com/async/irc?",
                   "google.com/extern_chrome/",
                   "google.com/extern_js/",
                   "clients2.google.com/availability", // Seems not to get intercepted
                   "google.com/searchdomaincheck",
                   "accounts.google.com/ListAccounts",
                   "apis.google.com/_/scs/",
                   "apis.google.com/js/",
                   "apis.google.com/se/",
                   "apis.google.com/u/",
                   "google.com/ListAccounts",
                   "google.com/search?",
                   "google.com/webhp",
                   "www.google.com/?",
                   "google.com/url?",
                   "google.com/complete/search",
                   "google.com/s?",
                   "google.com/client_204",
                   "google.com/generate_204",
                   "google.com/gen_204",
                   "google.com/textinputassistant",
                   "google.com/_/scs/abc-static/_/",
                   "google.com/static/proxy.html",
                   "//images.google.com",
                   "google.com/images/",
                   "google.com/imghp",
                   "google.com/xjs/_/",
                   "google.com/compressiontest/gzip"
               ] ] ],
      action: "No Cookies"
    },
    { name: "Anonymize Google YouTube and Video",
      description: "Opt out of auto-sign-in to Google YouTube and Video",
      enabled: true,
      match: [ "url", "contains", [
          "//www.youtube.com/",
          "//youtube.com/",
          "youtubei/v1/log_interaction",
          "//video.google.com",
          "google.com/videohp"
      ] ],
      action: "No Cookies"
    },
    { name: "Anonymize Google Groups",
      description: "Opt out of auto-sign-in to Google Groups",
      enabled: true,
      match: [ "url", "contains", [
          "//groups.google.com/",
          "//gg.google.com",
          "//productforums.google.com"
      ] ],
      action: "No Cookies"
    },
    { name: "Anonymize Google Maps",
      description: "Opt out of auto-sign-in to Google Maps and Earth",
      enabled: true,
      match: [ "url", "contains", [
          ".google.com/maps",
          "//maps.google.com",
          "google.com/intl/earth"
      ] ],
      action: "No Cookies"
    },
    { name: "Anonymize Google Other Services",
      description: "Opt out of auto-sign-in to Google Books, News, Finance, Translate, Keep",
      enabled: true,
      match: [ "url", "contains", [
          "//news.google.com",
          "books.google.com",
          "finance.google.com",
          "google.com/finance",
          "translate.google.com",
          "keep.google.com",
          "google.com/keep"
      ] ],
      action: "No Cookies"
    },
    { name: "Block Google Talk",
      description: "Block access to talkgadget.google.com (to avoid back-door traffic to clients*.google.com)",
      enabled: false,
      match: [ "url", "matches", "https?://talkgadget\\.google\\.com" ],
      action: "Cancel"
    },
    { name: "Anonymize Microsoft Search",
      description: "Opt out of Microsoft/Bing search logging",
      enabled: true,
      match: [ "url", "contains", "bing.com" ],
      action: "No Cookies"
    },
    { name: "Example: Alert",
      description: "Example for alert.  To try, enable and visit https://foo.trigger-alert-example.org",
      enabled: true,
      match: [ "and",
               [ "url", "starts", [ "https://", "http://" ] ],
               [ "url", "contains", "trigger-alert-example.org" ]
             ],
      action: [ "Example: Alert", "Cancel" ]
    },
    { name: "Example: Block",
      description: "Example of blocking Yahoo! content on tumblr.com.  To try, enable and visit http://vanudest.tumblr.com",
      match: [ "url", "matches", "^https?://[\\w\\-\\.]*(sex|nude|porn|teen)[\\w\\-\\.]*.tumblr.com" ],
      enabled: true,
      action: "Block and Redirect"
    },
    { name: "Example: Auto-authorize",
      description: "Example of supplying Basic authorization based on URL",
      match: [ "url", "matches", "^https?://localhost/protected" ],
      enabled: true,
      action: "Example: Auto-authorize"
    },
    { name: "Disable compression",
      enabled: false,
      description: "Developers only!  Turn off all compression for traffic capture and inspection.",
      match: true,
      action: [ "No Compression" ]
    },
    { name: "Block Google Back-door Javascript",
      enabled: true,
      description: "Disallow retrieval of JavaScript by Google from back-door domains (clients*.google.com)",
      match: [ "url", "contains", "google.com" ],
      action: [ "Scrub CSP back-doors" ]
    },
    { name: "No Cache Based Tracking",
      enabled: false,
      description: "Disallow cache-header based tracking",
      match: true,
      action: [
          "No Cache Digest Tracking",
          "No Cache Timestamp Tracking"
      ]
    },
    { name: "Block Google Back-door Generators",
      enabled: false,
      description: "Block URLs that trigger traffic to back-door domains",
      match: [ "url", "contains", "gg.google.com/csi?v=2&s=youtube" ],
      action: "Cancel"
    },
    { name: "Debug Google back-doors",
      enabled: false,
      description: "Test if browser bypasses Google back-door domains \"clients[1-9].google.com\".  To use, enable this rule, visit such a domain and check the debug page.",
      match: [ "url", "matches", "^https?://clients[1-9]\\.google\\.com" ],
      action: "Debug"
    },
    { name: "Debug all",
      enabled: false,
      description: "Debug all requests.  Use sparingly, slows things down considerably",
      match: true,
      action: "Debug"
    }
];

// Set defaults
var GLOBAL__options_default = {
    // Disabled globally by default, have to "opt in" to the extension
    enabled: false,
    // Allow cookies?
    cookies: true,
    // Debug capture slows things down, so keep it off by default
    debug: false,
    // Number of debug requests in FIFO
    debug_requests_count: 200,
    // New tab URL, useful to override nosy "new tab" URLs from certain vendors
    newtab_url: "",
    // Enable icon on the toolbar?
    enable_icon: true,
    // Action: list
    actions: GLOBAL__default_actions,
    // Rules list
    rules: GLOBAL__default_rules,
    // Options version
    options_version: "1.0.3"
};

// $Id: defaults.js,v 1.35 2014/12/28 04:09:41 hin Exp $
